# Change Log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

## [0.0.1] - 2020-08-13
- initial port of existing routines from pysat
